@@ -35,7 +35,7 @@ import traceback
 import json
 
 from PyQt5.QtCore import PYQT_VERSION_STR, QT_VERSION_STR, pyqtSlot
-from PyQt5.QtWidgets import QApplication, QStyleFactory, QMessageBox
+from PyQt5.QtWidgets import QApplication, QMessageBox
 
 # Disable sandbox support for QtWebEngine (required on some Linux distros
 # for the QtWebEngineWidgets to be rendered, otherwise no timeline is visible).
@@ -148,6 +148,13 @@ class OpenShotApp(QApplication):
         if self.mode == "unittest" or not self.settings.get('send_metrics'):
             sentry.disable_tracing()
 
+        # Empty window
+        self.window = None
+
+        # Instantiate Theme Manager (Singleton)
+        from themes.manager import ThemeManager
+        self.theme_manager = ThemeManager(self)
+
     def show_environment(self, info, openshot):
         log = self.log
         try:
@@ -199,8 +206,7 @@ class OpenShotApp(QApplication):
         Initialize GUI and main window.
         :return: bool: True if the GUI has no errors, False if we fail to initialize the GUI
         """
-        from classes import language, sentry, ui_util, logger_libopenshot
-        from PyQt5.QtGui import QFont, QFontDatabase as QFD
+        from classes import language, sentry, logger_libopenshot
 
         _ = self._tr
         info = self.info
@@ -210,9 +216,6 @@ class OpenShotApp(QApplication):
         language.init_language()
         sentry.set_tag("locale", info.CURRENT_LANGUAGE)
 
-        # Load ui theme if not set by OS
-        ui_util.load_theme()
-
         # Test for permission issues (and display message if needed)
         try:
             log.debug("Testing write access to user directory")
@@ -247,30 +250,6 @@ class OpenShotApp(QApplication):
         # Track which dockable window received a context menu
         self.context_menu_object = None
 
-        # Set Font for any theme
-        log.debug("Loading UI theme")
-        if self.settings.get("theme") != "No Theme":
-            # Load embedded font
-            font_path = os.path.join(info.IMAGES_PATH, "fonts", "Ubuntu-R.ttf")
-            if os.path.exists(font_path):
-                log.info("Setting font to %s", font_path)
-                try:
-                    font_id = QFD.addApplicationFont(font_path)
-                    font_family = QFD.applicationFontFamilies(font_id)[0]
-                    font = QFont(font_family)
-                    font.setPointSizeF(10.5)
-                    QApplication.setFont(font)
-                except Exception:
-                    log.warning("Error setting Ubuntu-R.ttf QFont", exc_info=1)
-
-        # Set Dark Theme, if selected
-        if self.settings.get("theme") == "Humanity: Dark":
-            log.info("Setting custom dark theme")
-            self.setStyle(QStyleFactory.create("Fusion"))
-            darkPalette = ui_util.make_dark_palette(self.palette())
-            self.setPalette(darkPalette)
-            self.setStyleSheet("QToolTip { color: #ffffff; background-color: #2a82da; border: 0px solid white; }")
-
         # Create main window
         from windows.main_window import MainWindow
         log.debug("Creating main interface window")
@@ -287,6 +266,9 @@ class OpenShotApp(QApplication):
         # Connect our exit signals
         self.aboutToQuit.connect(self.cleanup)
 
+        # Show main window
+        self.window.show()
+
         args = self.args
         if len(args) < 2:
             # Recover backup file (this can't happen until after the Main Window has completely loaded)
