@@ -24,6 +24,7 @@
  You should have received a copy of the GNU General Public License
  along with OpenShot Library.  If not, see <http://www.gnu.org/licenses/>.
  """
+import copy
 import functools
 import locale
 import os
@@ -43,10 +44,10 @@ from xml.parsers.expat import ExpatError
 
 from PyQt5.QtCore import Qt, QCoreApplication, QTimer, QSize, pyqtSignal, pyqtSlot
 from PyQt5.QtWidgets import (
-    QMessageBox, QDialog, QFileDialog, QDialogButtonBox, QPushButton
+    QMessageBox, QDialog, QFileDialog, QDialogButtonBox, QPushButton, QWidget, QLineEdit, QComboBox, QSpinBox, QCheckBox
 )
 from PyQt5.QtGui import QIcon
-
+from functools import partial
 from classes import info
 from classes import ui_util
 from classes import openshot_rc  # noqa
@@ -86,8 +87,13 @@ class Export(QDialog):
 
         # Add buttons to interface
         self.cancel_button = QPushButton(_('Cancel'))
+        self.cancel_button.setObjectName("cancelButton")
         self.export_button = QPushButton(_('Export Video'))
+        self.export_button.setObjectName("acceptButton")
         self.close_button = QPushButton(_('Done'))
+        self.restoring_defaults = False
+        self.restore_defaults_button.clicked.connect(self.restore_defaults)
+
         self.buttonBox.addButton(self.close_button, QDialogButtonBox.RejectRole)
         self.buttonBox.addButton(self.export_button, QDialogButtonBox.AcceptRole)
         self.buttonBox.addButton(self.cancel_button, QDialogButtonBox.RejectRole)
@@ -104,9 +110,11 @@ class Export(QDialog):
         # Set OMP thread disabled flag (for stability)
         openshot.Settings.Instance().HIGH_QUALITY_SCALING = True
 
-        project_timeline = get_app().window.timeline_sync.timeline
+        # Copy project (so we don't change data in our current project)
+        self.project = copy.deepcopy(get_app().project)
 
         # Clear timeline preview cache (to get more available memory)
+        project_timeline = get_app().window.timeline_sync.timeline
         project_timeline.ClearAllCache()
 
         # Get the original timeline settings
@@ -132,7 +140,7 @@ class Export(QDialog):
 
         # Load the "export" Timeline reader with the JSON from the real timeline
         try:
-            json_timeline = json.dumps(get_app().project._data)
+            json_timeline = json.dumps(self.project._data)
             self.timeline.SetJson(json_timeline)
         except Exception as ex:
             msg = QMessageBox()
@@ -195,6 +203,8 @@ class Export(QDialog):
         self.cboChannelLayout.currentIndexChanged.connect(self.updateChannels)
         self.ExportFrame.connect(self.updateProgressBar)
         self.btnBrowseProfiles.clicked.connect(self.btnBrowseProfiles_clicked)
+        self.checkStartFirstClip.toggled.connect(partial(self.updateFrameRate, True))
+        self.checkEndLastClip.toggled.connect(partial(self.updateFrameRate, True))
 
         # ********* Advanced Profile List **********
         # Loop through profiles
@@ -228,12 +238,6 @@ class Export(QDialog):
                     # This exception occurs when there's a problem parsing the Profile file - display a message and continue
                     log.error("Failed to parse file '%s' as a profile: %s" % (profile_path, e))
 
-        # Loop through sorted profiles
-        for profile_name in sorted(self.profile_names):
-            # Add to dropdown
-            self.cboProfile.addItem(self.getProfileName(self.getProfilePath(profile_name)),
-                                    self.getProfilePath(profile_name))
-
         # ********* Simple Project Type **********
         # load the simple project type dropdown
         presets = []
@@ -278,6 +282,27 @@ class Export(QDialog):
         # Determine the length of the timeline (in frames)
         self.updateFrameRate()
 
+        # Load previous settings (if any)
+        self.load_settings()
+
+    def restore_defaults(self):
+        """
+        Restore defaults by closing and reopening the dialog.
+        """
+        # Clear the saved settings
+        get_app().updates.ignore_history = True
+        get_app().updates.update(["export_settings"], None)
+        get_app().updates.ignore_history = False
+
+        log.info("Cleared last-export_settings.")
+
+        # Close the current dialog
+        self.restoring_defaults = True
+        self.close()
+
+        # Re-open the export dialog (calling the dialog anew)
+        QTimer.singleShot(0, get_app().window.actionExportVideo.trigger)
+
     def getProfilePath(self, profile_name):
         """Get the profile path that matches the name"""
         for profile, path in self.profile_paths.items():
@@ -321,7 +346,7 @@ class Export(QDialog):
         # Update channels to match layout
         self.txtChannels.setValue(channels)
 
-    def updateFrameRate(self):
+    def updateFrameRate(self, set_limits=True):
         """Callback for changing the frame rate"""
         # Adjust the main timeline reader
         self.timeline.info.width = self.txtWidth.value()
@@ -338,12 +363,24 @@ class Export(QDialog):
         else:
             self.timeline.info.has_audio = True
 
-        # Determine max frame (based on clips)
-        self.timeline_length_int = self.timeline.GetMaxFrame()
+        if set_limits:
+            if self.checkEndLastClip.isChecked():
+                # Set end frame to last clip (right edge)
+                timeline_length_int = self.timeline.GetMaxFrame()
+            else:
+                # Set end frame to project length (full timeline)
+                timeline_length_int = self.timeline.info.video_length
 
-        # Set the min and max frame numbers for this project
-        self.txtStartFrame.setValue(1)
-        self.txtEndFrame.setValue(self.timeline_length_int)
+            if self.checkStartFirstClip.isChecked():
+                # Set the start frame to the first clip position
+                timeline_start_int = self.timeline.GetMinFrame()
+            else:
+                # Set the start frame to the start of the project (0.0)
+                timeline_start_int = 1
+
+            # Set the min and max frame numbers for this project
+            self.txtStartFrame.setValue(timeline_start_int)
+            self.txtEndFrame.setValue(timeline_length_int)
 
         # Calculate differences between editing/preview FPS and export FPS
         current_fps = get_app().project.get("fps")
@@ -747,7 +784,7 @@ class Export(QDialog):
         self.txtFileName.setEnabled(False)
         self.lblFolderPath.setEnabled(False)
         self.txtExportFolder.setEnabled(False)
-        self.tabWidget.setEnabled(False)
+        self.exportTabs.setEnabled(False)
         self.export_button.setEnabled(False)
         self.btnBrowse.setEnabled(False)
 
@@ -757,12 +794,14 @@ class Export(QDialog):
         self.txtFileName.setEnabled(True)
         self.lblFolderPath.setEnabled(True)
         self.txtExportFolder.setEnabled(True)
-        self.tabWidget.setEnabled(True)
+        self.exportTabs.setEnabled(True)
         self.export_button.setEnabled(True)
         self.btnBrowse.setEnabled(True)
 
     def accept(self):
         """ Start exporting video """
+        # Save export settings
+        self.save_settings()
 
         # Build the export window title
         def titlestring(sec, fps, mess):
@@ -905,14 +944,18 @@ class Export(QDialog):
 
         # Rescale all keyframes (if needed)
         if self.export_fps_factor != 1.0:
-            # Get a copy of rescaled project data (this does not modify the active project)
-            rescaled_app_data = get_app().project.rescale_keyframes(self.export_fps_factor)
+            # Update project data with rescaled keyframes
+            self.project.rescale_keyframes(self.export_fps_factor)
 
-            # Load the "export" Timeline reader with the JSON from the real timeline
-            self.timeline.SetJson(json.dumps(rescaled_app_data))
+            # Apply new profile (and any FPS precision updates) to project data
+            profile = openshot.Profile(self.cboSimpleVideoProfile.currentData())
+            self.project.apply_profile(profile)
+
+            # Update the timeline with rescaled keyframes and adjusted profile's FPS precision
+            self.timeline.SetJson(json.dumps(self.project._data))
 
         # Re-update the timeline FPS again (since the timeline just got clobbered)
-        self.updateFrameRate()
+        self.updateFrameRate(set_limits=False)
 
         # Set MaxSize (so we don't have any downsampling)
         self.timeline.SetMaxSize(video_settings.get("width"), video_settings.get("height"))
@@ -1122,7 +1165,77 @@ class Export(QDialog):
             # Accept dialog
             super(Export, self).accept()
 
+    def save_settings(self):
+        if self.restoring_defaults:
+            return  # Ignore saving if we are actively restoring defaults
+
+        # Create a list to store the settings in order
+        settings = []
+
+        # Iterate over all children in the dialog in the order they are defined
+        for child in self.findChildren(QWidget):
+            if child.objectName().startswith("qt_"):
+                continue
+            setting = {}
+            if isinstance(child, QLineEdit):
+                setting['name'] = child.objectName()
+                setting['type'] = 'QLineEdit'
+                setting['value'] = child.text()
+            elif isinstance(child, QComboBox):
+                setting['name'] = child.objectName()
+                setting['type'] = 'QComboBox'
+                setting['value'] = child.currentIndex()
+            elif isinstance(child, QSpinBox):
+                setting['name'] = child.objectName()
+                setting['type'] = 'QSpinBox'
+                setting['value'] = child.value()
+            elif isinstance(child, QCheckBox):
+                setting['name'] = child.objectName()
+                setting['type'] = 'QCheckBox'
+                setting['value'] = child.isChecked()
+            # Append the setting to the list
+            if setting:
+                settings.append(setting)
+
+        # Save all settings as a JSON string
+        get_app().updates.ignore_history = True
+        get_app().updates.update(["export_settings"], settings)
+        get_app().updates.ignore_history = False
+
+        log.info("Export settings saved: %s", settings)
+
+    def load_settings(self):
+        # Load the JSON string from settings
+        settings = get_app().project.get("export_settings")
+
+        if not settings:
+            log.info("No saved settings found.")
+            return
+
+        # Iterate over the list of settings and apply them in order
+        for setting in settings:
+            widget = self.findChild(QWidget, setting['name'])
+            if widget:
+                if setting['type'] == 'QLineEdit':
+                    widget.setText(setting.get('value', ''))
+                elif setting['type'] == 'QComboBox':
+                    widget.setCurrentIndex(setting.get('value', 0))
+                elif setting['type'] in ['QSpinBox', 'QDoubleSpinBox']:
+                    widget.setValue(setting.get('value', widget.minimum()))
+                elif setting['type'] == 'QCheckBox':
+                    widget.setChecked(setting.get('value', False))
+
+        # Update start / end frame after loading settings
+        if self.checkStartFirstClip.isChecked():
+            self.updateFrameRate(True)
+        if self.checkEndLastClip.isChecked():
+            self.updateFrameRate(True)
+
+        log.info("Export settings loaded: %s", settings)
+
     def reject(self):
+        self.save_settings()
+
         if self.exporting and not self.close_button.isVisible():
             # Show confirmation dialog
             _ = get_app()._tr
