@@ -31,14 +31,16 @@ import json
 import re
 import glob
 import functools
+import uuid
 
 from PyQt5.QtCore import (
     QMimeData, Qt, pyqtSignal, QEventLoop, QObject,
-    QSortFilterProxyModel, QItemSelectionModel, QPersistentModelIndex,
+    QSortFilterProxyModel, QItemSelectionModel, QPersistentModelIndex, QModelIndex
 )
 from PyQt5.QtGui import (
     QIcon, QStandardItem, QStandardItemModel
 )
+from PyQt5.QtWidgets import QAbstractItemView
 from classes import updates
 from classes import info
 from classes.image_types import get_media_type
@@ -95,6 +97,12 @@ class FileFilterProxyModel(QSortFilterProxyModel):
         # Return Mimedata
         return data
 
+    def get_file_index(self, file_id):
+        # Find the index in the proxy model based on the file ID
+        if file_id in self.parent.model_ids:
+            return self.mapFromSource(QModelIndex(self.parent.model_ids[file_id]))
+        return QModelIndex()
+
     def __init__(self, **kwargs):
         if "parent" in kwargs:
             self.parent = kwargs["parent"]
@@ -111,7 +119,7 @@ class FilesModel(QObject, updates.UpdateInterface):
     def changed(self, action):
 
         # Something was changed in the 'files' list
-        if (len(action.key) >= 1 and action.key[0].lower() == "files") or action.type == "load":
+        if action and ((len(action.key) >= 1 and action.key[0].lower() == "files") or action.type == "load"):
             # Refresh project files model
             if action.type == "insert":
                 # Don't clear the existing items if only inserting new things
@@ -271,6 +279,7 @@ class FilesModel(QObject, updates.UpdateInterface):
         # Make sure we're working with a list of files
         if not isinstance(files, (list, tuple)):
             files = [files]
+        scroll_to_files = []
 
         start_count = len(files)
         for count, filepath in enumerate(files):
@@ -281,6 +290,8 @@ class FilesModel(QObject, updates.UpdateInterface):
 
             # If this file is already found, exit
             if new_file:
+                # Still add the file (to be selected and scrolled to)
+                scroll_to_files.append(new_file)
                 del new_file
                 continue
 
@@ -361,6 +372,7 @@ class FilesModel(QObject, updates.UpdateInterface):
 
                 # Save file
                 new_file.save()
+                scroll_to_files.append(new_file)
 
                 if start_count > 15:
                     message = _("Importing %(count)d / %(total)d") % {
@@ -379,13 +391,23 @@ class FilesModel(QObject, updates.UpdateInterface):
                 # Log exception
                 log.warning("Failed to import {}: {}".format(filepath, ex))
 
-                if not quiet:
-                    # Show message box to user
+                if not quiet and start_count == 1:
+                    # Show message box to user (if importing a single file)
                     app.window.invalidImage(filename)
 
         # Reset list of ignored paths
         self.ignore_image_sequence_paths = []
 
+        # Select all new files (clear previous selection)
+        self.selection_model.clearSelection()
+        for file_object in scroll_to_files:
+            # Get the index of the newly added file in the proxy model
+            index = self.proxy_model.get_file_index(file_object.id)
+            if index.isValid():
+                # Select & scroll to selection
+                self.selection_model.select(index, QItemSelectionModel.Select | QItemSelectionModel.Rows)
+                get_app().window.filesView.scrollTo(index.siblingAtColumn(0), QAbstractItemView.PositionAtCenter)
+
         message = _("Imported %(count)d files") % {"count": len(files) - 1}
         app.window.statusBar.showMessage(message, 3000)
 
@@ -461,11 +483,14 @@ class FilesModel(QObject, updates.UpdateInterface):
         }
         return parameters
 
-    def process_urls(self, qurl_list):
+    def process_urls(self, qurl_list, import_quietly=False, prevent_image_seq=False):
         """Recursively process QUrls from a QDropEvent"""
-        import_quietly = False
         media_paths = []
 
+        # Transaction
+        tid = str(uuid.uuid4())
+        get_app().updates.transaction_id = tid
+
         for uri in qurl_list:
             filepath = uri.toLocalFile()
             if not os.path.exists(filepath):
@@ -490,7 +515,8 @@ class FilesModel(QObject, updates.UpdateInterface):
         # Import all new media files
         media_paths.sort()
         log.debug("Importing file list: {}".format(media_paths))
-        self.add_files(media_paths, quiet=import_quietly)
+        self.add_files(media_paths, quiet=import_quietly, prevent_image_seq=prevent_image_seq)
+        get_app().updates.transaction_id = None
 
     def update_file_thumbnail(self, file_id):
         """Update/re-generate the thumbnail of a specific file"""
@@ -530,6 +556,11 @@ class FilesModel(QObject, updates.UpdateInterface):
             item.setIcon(thumb_icon)
             item.setText(name)
 
+            # Update display name
+            text_index = id_index.sibling(id_index.row(), 1)
+            item = m.itemFromIndex(text_index)
+            item.setText(name)
+
             # Emit signal when model is updated
             self.ModelRefreshed.emit()
 
